@@ -66,9 +66,11 @@ void Sweeper::EvaluateThemeName()
 
         Redraw();
       }
-      break;
+      return;
     }
   }
+
+  assert(false);
 }
 
 void Sweeper::CalcSize()
