@@ -21,11 +21,13 @@
 
 #include <Lum/OS/Probe.h>
 
+#include <Lum/Base/L10N.h>
 #include <Lum/Base/Object.h>
 #include <Lum/Base/String.h>
 #include <Lum/Base/Util.h>
 
 #include <Lum/Dlg/About.h>
+#include <Lum/Dlg/Help.h>
 #include <Lum/Dlg/Msg.h>
 
 #include <Lum/Model/Action.h>
@@ -36,7 +38,6 @@
 
 #include <Lum/Array.h>
 #include <Lum/Boolean.h>
-#include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Dialog.h>
 #include <Lum/Grid.h>
@@ -51,7 +52,6 @@
 #include <Lum/Space.h>
 #include <Lum/StatusLine.h>
 #include <Lum/View.h>
-#include <Lum/WindowGroup.h>
 
 #include "config.h"
 #include "Configuration.h"
@@ -87,16 +87,11 @@ public:
 
   void PreInit()
   {
-    Lum::Button           *button;
     Lum::ButtonRow        *bRow;
     Lum::Panel            *panel;
     Lum::Table            *table;
-    Lum::WindowGroup      *wGroup;
     Lum::Model::HeaderRef headerModel;
 
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-
     panel=new Lum::VPanel();
     panel->SetFlex(true,true);
 
@@ -116,21 +111,11 @@ public:
 
     panel->Add(new Lum::VSpace());
 
-    bRow=new Lum::ButtonRow();
+    bRow=Lum::ButtonRow::CreateClose(GetClosedAction());
     bRow->SetFlex(true,false);
     panel->Add(bRow);
 
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(GetClosedAction());
-    button->SetType(Lum::Button::typeDefault);
-    button->SetText(L"_Close");
-
-    bRow->Add(button);
-
-    wGroup->SetMain(panel);
-
-    SetTop(wGroup);
+    SetMain(panel);
 
     Dialog::PreInit();
   }
@@ -155,28 +140,19 @@ public:
                     sweeper->GetAreaHeight(),
                     sweeper->GetMines());
 
-    AttachModel(closeAction);
+    Observe(closeAction);
 
     name->Set(score->list[pos].name);
-    AttachModel(name);
-  }
-
-  ~ScoreEdit()
-  {
-    UnattachModel(name);
-    UnattachModel(closeAction);
+    Observe(name);
   }
 
   void PreInit()
   {
-    Lum::Button      *button;
-    Lum::ButtonRow   *bRow;
-    Lum::Grid        *grid;
-    Lum::Panel       *panel;
-    Lum::String      *string;
-    Lum::WindowGroup *wGroup;
-
-    wGroup=new Lum::WindowGroup();
+    Lum::ButtonRow *bRow;
+    Lum::Grid      *grid;
+    Lum::Panel     *panel;
+    Lum::String    *string;
+    Lum::Text      *text;
 
     panel=new Lum::VPanel();
     panel->SetFlex(true,true);
@@ -185,63 +161,51 @@ public:
     grid->SetSpace(true,true);
 
     for (size_t x=0; x<10; x++) {
-      Lum::Text *text;
+      if (x==pos) {
+        text=new Lum::Text();
+        text->SetText(Lum::Base::NumberToWString((unsigned long)x+1)+L":");
+        grid->SetObject(0,x,text);
 
-      text=new Lum::Text();
-      text->SetText(Lum::Base::NumberToWString((unsigned long)x+1)+L":");
-      grid->SetObject(0,x,text);
-
-      if (pos==x) {
         string=new Lum::String();
         string->SetFlex(true,false);
         string->SetWidth(Lum::Base::Size::stdCharWidth,10);
         string->SetModel(name);
         grid->SetObject(1,x,string);
+
+        text=new Lum::Text();
+        text->SetAlignment(Lum::Text::left);
+        text->SetFlex(true,false);
+        text->SetText(Lum::Base::NumberToWString((unsigned long)score->list[x].time)+L" second(s)");
+        grid->SetObject(2,x,text);
       }
-      else {
+      else if (x<score->list.size() && (x+1==pos|| x+2==pos || x==pos+1 || x==pos+2)) {
+        text=new Lum::Text();
+        text->SetText(Lum::Base::NumberToWString((unsigned long)x+1)+L":");
+        grid->SetObject(0,x,text);
+
         text=new Lum::Text();
         text->SetFlex(true,false);
         text->SetAlignment(Lum::Text::left);
-        if (x<score->list.size()) {
-          text->SetText(score->list[x].name);
-        }
-        else {
-          text->SetText(L"");
-        }
+        text->SetText(score->list[x].name);
         grid->SetObject(1,x,text);
-      }
 
-      text=new Lum::Text();
-      text->SetAlignment(Lum::Text::left);
-      text->SetFlex(true,false);
-      if (x<score->list.size()) {
+        text=new Lum::Text();
+        text->SetAlignment(Lum::Text::left);
+        text->SetFlex(true,false);
         text->SetText(Lum::Base::NumberToWString((unsigned long)score->list[x].time)+L" second(s)");
+        grid->SetObject(2,x,text);
       }
-      else {
-        text->SetText(L"");
-      }
-      grid->SetObject(2,x,text);
     }
 
     panel->Add(grid);
 
     panel->Add(new Lum::VSpace());
 
-    bRow=new Lum::ButtonRow();
+    bRow=Lum::ButtonRow::CreateClose(closeAction);
     bRow->SetFlex(true,false);
     panel->Add(bRow);
 
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(closeAction);
-    button->SetType(Lum::Button::typeDefault);
-    button->SetText(L"_Close");
-
-    bRow->Add(button);
-
-    wGroup->SetMain(panel);
-
-    SetTop(wGroup);
+    SetMain(panel);
 
     Dialog::PreInit();
   }
@@ -278,8 +242,8 @@ public:
   {
     okAction->Disable();
 
-    AttachModel(okAction);
-    AttachModel(selection);
+    Observe(okAction);
+    Observe(selection);
 
     for (size_t i=0; i<themes.size(); ++i) {
       Lum::Model::ListTable::StdEntry *entry;
@@ -292,28 +256,18 @@ public:
     }
   }
 
-  ~SelectTheme()
-  {
-    UnattachModel(selection);
-    UnattachModel(okAction);
-  }
-
   void PreInit()
   {
-    Lum::Button           *button;
     Lum::ButtonRow        *bRow;
     Lum::Panel            *panel;
     Lum::Table            *table;
-    Lum::WindowGroup      *wGroup;
     Lum::Model::HeaderRef headerModel;
 
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-    wGroup->SetWidth(Lum::Base::Size::modePixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
-    wGroup->SetHeight(Lum::Base::Size::modePixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
 
     panel=new Lum::VPanel();
     panel->SetFlex(true,true);
+    panel->SetWidth(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetWidth()*80)/100);
+    panel->SetHeight(Lum::Base::Size::pixel,(GetWindow()->GetParent()->GetHeight()*80)/100);
 
     headerModel=new Lum::Model::HeaderImpl();
     headerModel->AddColumn(L"Theme name",Lum::Base::Size::stdCharWidth,25);
@@ -330,27 +284,11 @@ public:
 
     panel->Add(new Lum::VSpace());
 
-    bRow=new Lum::ButtonRow();
+    bRow=Lum::ButtonRow::CreateOkCancel(okAction,GetClosedAction());
     bRow->SetFlex(true,false);
     panel->Add(bRow);
 
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(okAction);
-    button->SetType(Lum::Button::typeCommit);
-    button->SetText(L"_Ok");
-    bRow->Add(button);
-
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(GetClosedAction());
-    button->SetType(Lum::Button::typeCancel);
-    button->SetText(L"_Cancel");
-    bRow->Add(button);
-
-    wGroup->SetMain(panel);
-
-    SetTop(wGroup);
+    SetMain(panel);
 
     Dialog::PreInit();
   }
@@ -410,10 +348,10 @@ public:
     oneButtonMode(new Lum::Model::Boolean(GetOneButtonMode())),
     themeName(new Lum::Model::String())
   {
-    AttachModel(smallAction);
-    AttachModel(mediumAction);
-    AttachModel(bigAction);
-    AttachModel(themeAction);
+    Observe(smallAction);
+    Observe(mediumAction);
+    Observe(bigAction);
+    Observe(themeAction);
 
     horiz->SetRange(1,30);
     vert->SetRange(1,30);
@@ -422,14 +360,6 @@ public:
     themeName->Set(::themeName);
   }
 
-  ~Settings()
-  {
-    UnattachModel(themeAction);
-    UnattachModel(smallAction);
-    UnattachModel(mediumAction);
-    UnattachModel(bigAction);
-  }
-
   void PreInit()
   {
     Lum::Boolean     *boolean;
@@ -440,9 +370,6 @@ public:
     Lum::Array       *array;
     Lum::Slider      *slider;
     Lum::TextValue   *textValue;
-    Lum::WindowGroup *wGroup;
-
-    wGroup=new Lum::WindowGroup();
 
     panel=new Lum::VPanel();
 
@@ -516,21 +443,11 @@ public:
 
     panel->Add(new Lum::VSpace());
 
-    bRow=new Lum::ButtonRow();
+    bRow=Lum::ButtonRow::CreateClose(GetClosedAction());
     bRow->SetFlex(true,false);
     panel->Add(bRow);
 
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(GetClosedAction());
-    button->SetType(Lum::Button::typeDefault);
-    button->SetText(L"_Close");
-
-    bRow->Add(button);
-
-    wGroup->SetMain(panel);
-
-    SetTop(wGroup);
+    SetMain(panel);
 
     Dialog::PreInit();
   }
@@ -600,43 +517,25 @@ public:
     aboutAction(new Lum::Model::Action),
     timerAction(new Lum::Model::Action)
   {
-    AttachModel(newGameAction);
-    AttachModel(hiscoreAction);
-    AttachModel(settingsAction);
-    AttachModel(helpAction);
-    AttachModel(aboutAction);
-    AttachModel(timerAction);
+    Observe(newGameAction);
+    Observe(hiscoreAction);
+    Observe(settingsAction);
+    Observe(helpAction);
+    Observe(aboutAction);
+    Observe(timerAction);
 
-    AttachModel(GetOpenedAction());
-  }
-
-  ~MyWindow()
-  {
-    UnattachModel(GetOpenedAction());
-
-    UnattachModel(timerAction);
-    UnattachModel(aboutAction);
-    UnattachModel(helpAction);
-    UnattachModel(settingsAction);
-    UnattachModel(hiscoreAction);
-    UnattachModel(newGameAction);
+    Observe(GetOpenedAction());
   }
 
   void PreInit()
   {
     Lum::Button      *button;
-    Lum::MenuStrip   *strip;
-    Lum::Menu        *menu;
     Lum::Panel       *vPanel,*hPanel;
     Lum::View        *view;
-    Lum::WindowGroup *wGroup;
     size_t           digitWidth,widestDigit;
     std::wstring     timeFormat,marksFormat;
     Lum::OS::FontRef font;
 
-    wGroup=new Lum::WindowGroup();
-    wGroup->SetFlex(true,true);
-
     vPanel=new Lum::VPanel;
     vPanel->SetFlex(true,true);
 
@@ -674,7 +573,7 @@ public:
     marks->SetFont(font);
     marks->SetStyle(Lum::OS::Font::bold);
     marks->SetAlignment(Lum::Text::right);
-    marks->SetMinWidth(Lum::Base::Size::modePixel,font->StringWidth(marksFormat));
+    marks->SetMinWidth(Lum::Base::Size::pixel,font->StringWidth(marksFormat));
     marks->SetText(L"0");
 
     hPanel->Add(marks);
@@ -689,7 +588,7 @@ public:
     time->SetFont(font);
     time->SetStyle(Lum::OS::Font::bold);
     time->SetAlignment(Lum::Text::centered);
-    time->SetMinWidth(Lum::Base::Size::modePixel,font->StringWidth(timeFormat));
+    time->SetMinWidth(Lum::Base::Size::pixel,font->StringWidth(timeFormat));
     time->SetText(L"0000");
 
     hPanel->Add(time);
@@ -703,38 +602,32 @@ public:
 
     sweeper=new Sweeper();
     sweeper->SetFlex(true,true);
-    AttachModel(sweeper->GetStatusModel());
-    AttachModel(sweeper->GetMarksModel());
+    Observe(sweeper->GetStatusModel());
+    Observe(sweeper->GetMarksModel());
 
     view->SetObject(sweeper);
     vPanel->Add(view);
 
-    strip=new Lum::MenuStrip();
+    SetMain(vPanel);
 
-    menu=new Lum::Menu();
-    menu->AddActionItem(L"_New Game",newGameAction,Lum::OS::qualifierControl,L"n");
-    menu->AddSeparator();
-    menu->AddActionItem(L"_Hiscore...",hiscoreAction);
-    menu->AddSeparator();
-    menu->AddActionItem(L"_Quit",GetClosedAction(),Lum::OS::qualifierControl,L"q");
-    strip->AddPullDownMenu(L"_Game",menu);
+    Lum::MenuDesc *menu=new Lum::MenuDesc();
 
-    menu=new Lum::Menu();
-    menu->AddActionItem(L"_Settings...",settingsAction);
+    menu
+      ->AddMenuItemSub(_ld(menuProject))
+        ->AddMenuItemAction(L"_New Game",Lum::OS::qualifierControl,L"n",newGameAction)
+        ->AddSeparator()
+        ->AddMenuItemAction(L"_Hiscore...",hiscoreAction)
+        ->AddSeparator()
+        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
+    menu
+      ->AddMenuItemSub(L"Settings")
+        ->AddMenuItemAction(L"_Settings...",settingsAction);
+    menu
+      ->AddMenuItemSub(_ld(menuHelp))
+        ->AddMenuItemAction(_ld(menuHelpHelp),helpAction)
+        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
 
-    strip->AddPullDownMenu(L"_Settings",menu);
-
-    menu=new Lum::Menu();
-    menu->AddActionItem(L"_Help...",helpAction);
-    menu->AddSeparator();
-    menu->AddActionItem(L"_About...",aboutAction);
-
-    strip->AddPullDownMenu(L"_Help",menu);
-
-    wGroup->SetMenuStrip(strip);
-    wGroup->SetMain(vPanel);
-
-    SetTop(wGroup);
+    SetMenu(menu);
 
     Dialog::PreInit();
   }
@@ -871,19 +764,18 @@ public:
       Lum::Dlg::About::Show(this,info);
     }
     else if (model==helpAction && helpAction->IsFinished()) {
-      Lum::Dlg::Msg::ShowOk(this,
-                            L"Game playing hints...",
-                            L"In normal mode, you just open a square by pressing\n"
-                            L"the left button on it.\n"
-                            L"You mark a square as containing a bomb by pressing\n"
-                            L"the right mouse button on it.\n"
-                            L"\n"
-                            L"If you don't have a right mouse button you can\n"
-                            L"activate the one button mouse mode in the settings\n"
-                            L"dialog.\n"
-                            L"In this case you mark squares as containing a bomb with\n"
-                            L"the left mouse button, and open a square by doing a\n"
-                            L"diagonal stroke over the square.");
+      Lum::Dlg::Help::Show(this,
+                           L"In normal mode, you just open a square by pressing\n"
+                           L"the left button on it.\n"
+                           L"You mark a square as containing a bomb by pressing\n"
+                           L"the right mouse button on it.\n"
+                           L"\n"
+                           L"If you don't have a right mouse button you can\n"
+                           L"activate the one button mouse mode in the settings\n"
+                           L"dialog.\n"
+                           L"In this case you mark squares as containing a\n"
+                           L"bomb with the left mouse button, and open a square\n"
+                           L"by doing a diagonal stroke over the square.");
     }
     else if (sweeper!=NULL && model==sweeper->GetStatusModel()) {
       if (sweeper->GetStatus()==Sweeper::won) {
